<?php
/**
 * Text field for metaboxes
 *
 * @package "All In One Meta" library
 * @since   1.0.0
 * @version 1.0.0
 */

// Prevent direct script access.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'No direct script access allowed' );
}

if ( ! class_exists( 'AIOM_Base_Field' ) ) {
	require_once( AIOM_PATH . 'core/fields/base-field.php' );
}

if ( ! class_exists( 'Boombox_AIOM_Icons_Dropdown_Field' ) && class_exists( 'AIOM_Base_Field' ) ) {
	
	/**
	 * Class Boombox_AIOM_Icons_Dropdown_Field
	 */
	final class Boombox_AIOM_Icons_Dropdown_Field extends AIOM_Base_Field {
		
		/**
		 * Holds field choices
		 * @var array
		 */
		private $choices;
		
		/**
		 * Get field choices
		 * @return array
		 */
		private function get_choices() {
			return $this->choices;
		}
		
		/**
		 * AIOM_Select_Field constructor.
		 *
		 * @param array            $args
		 * @param bool|null|string $tab_id
		 * @param array            $data
		 * @param array            $structure
		 * @param string           $group
		 *
		 * @see AIOM_Base_Field::__construct()
		 */
		public function __construct( array $args, $tab_id, array $data, array $structure, $group ) {
			parent::__construct( $args, $tab_id, $data, $structure, $group );
			
			/***** Field choices */
			$this->choices = boombox_get_icomoon_icons_array();
		}
		
		/**
		 * Parse field arguments
		 *
		 * @param array $args Field arguments
		 *
		 * @return array
		 */
		public static function parse_field_args( $args ) {
			$args = wp_parse_args( $args, array(
				'id'                 => '',
				'name'               => '',
				'meta_key'           => '',
				'default'            => '',
				'label'              => '',
				'description'        => '',
				'priority'           => 0,
				'sub_priority'       => 0,
				'standalone'         => false,
				'attributes'         => '',
				'class'              => '',
				'wrapper_class'      => '',
				'wrapper_attributes' => '',
				'callback'           => 'sanitize_text_field',
				'value_callback'     => '',
				'active_callback'    => array(),
			) );
			
			return $args;
		}
		
		/**
		 * Enqueue color picker assets
		 */
		public static function enqueue() {
			
			$scripts = wp_scripts();
			
			$protocol = is_ssl() ? 'https' : 'http';
			$ui = $scripts->query( 'jquery-ui-core' );
			$min = boombox_get_minified_asset_suffix();
			
			wp_enqueue_style( 'jquery-ui-smoothness', $protocol . '://ajax.googleapis.com/ajax/libs/jqueryui/' . $ui->ver . '/themes/smoothness/jquery-ui' . $min . '.css', array(), boombox_get_assets_version() );
			wp_enqueue_style( 'boombox-icomoon-style', BOOMBOX_THEME_URL . 'fonts/icon-fonts/icomoon/icons.min.css', array(), boombox_get_assets_version() );
			boombox_enqueue_custom_icons_pack();
			wp_enqueue_style( 'boombox-aiom-icons-dropdown-styles', BOOMBOX_ADMIN_URL . 'metaboxes/aiom-custom-fields/icons-dropdown/style.css', array() );
			
			//wp_enqueue_script( 'boombox-aiom-icons-dropdown-scripts', BOOMBOX_ADMIN_URL . 'metaboxes/aiom-custom-fields/icons-dropdown/scripts' . $min . '.js', array( 'jquery-ui-selectmenu' ), boombox_get_assets_version(), true );
			wp_enqueue_script( 'boombox-aiom-icons-dropdown-scripts', BOOMBOX_ADMIN_URL . 'metaboxes/aiom-custom-fields/icons-dropdown/scripts.js', array( 'jquery-ui-selectmenu' ), boombox_get_assets_version(), true );
			
		}
		
		/**
		 * Get field wrapper classes
		 * @return string
		 */
		public function get_wrapper_class() {
			$classes = 'aiom-form-row aiom-form-row-text bb-custom-icons-dropdown';
			$passed_classes = parent::get_wrapper_class();
			if( $passed_classes ) {
				$classes .= ' ' . $passed_classes;
			}
			
			return $classes;
		}
		
		/**
		 * Render field
		 */
		public function render() {
			$label = $this->get_label(); ?>
			<div class="<?php echo $this->get_wrapper_class(); ?>" <?php echo $this->get_wrapper_attributes(); ?>>
				<div class="label-col<?php echo $label ? '' : ' label-col-empty'; ?>">
					<label for="<?php echo $this->get_id(); ?>"><?php echo esc_html( $label ); ?></label>
				</div>
				<div class="control-col">
					<select
						id="<?php echo $this->get_id(); ?>"
						class="<?php echo $this->get_class(); ?>"
						name="<?php echo $this->get_name(); ?><?php echo $this->has_attribute( 'multiple' ) ? '[]' : ''; ?>"
						<?php echo $this->get_attributes(); ?>>
						
						<?php foreach ( $this->get_choices() as $value ) {
							if ( is_array( $this->get_value() ) ) {
								$selected = selected( in_array( $value[ 'icon' ], $this->get_value(), true ), true, false );
							} else {
								$selected = selected( $value[ 'icon' ], $this->get_value(), false );
							} ?>
							<option value="<?php echo esc_html( esc_attr( $value[ 'icon' ] . $value[ 'postfix' ] ) ); ?>" data-class="<?php echo esc_attr( $value['prefix'] . $value[ 'icon' ] . $value[ 'postfix' ] ); ?>" <?php echo $selected; ?>><?php echo esc_html( $value[ 'name' ] ); ?></option>
						<?php } ?>
					</select>
					<?php if ( $description = $this->get_description() ) { ?>
						<p class="description"><?php echo $description; ?></p>
					<?php } ?>
				</div>
				<?php echo $this->get_active_callback(); ?>
			</div>
			<?php
		}
		
	}
	
}